/* 
 * glass - the openGL Articulated Skeleton System
 *
 * Copyright (C) 2001-2003  Robert Ancell <bob27@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __glass_interface_h__
#define __glass_interface_h__

typedef struct _GlassLibrary GlassLibrary;
typedef struct _GlassLibraryEntry GlassLibraryEntry;

#include "global.h"
#include "glass_model.h"
#include "glass_texture.h"
#include "glass_material.h"
#include "glass_surface.h"
#include "glass_variable.h"
#include "glass_apoint.h"

/* A library of models, so that each model can use eachothers variables, etc */
struct _GlassLibrary
{
  char *name;

  GlassLibraryEntry *first;
};

/* Linked list of GlassModels */
struct _GlassLibraryEntry
{
  GlassModel *model;

  GlassLibraryEntry *next, *last;
};

/* Return an empty library */
GlassLibrary *_glassLibraryNew(const char *name);

/* Set the name of the library */
int _glassLibrarySetName(GlassLibrary *library, const char *name);

/* Return the name of the library */
const char *_glassLibraryGetName(GlassLibrary *library);

/* Add a GLASS model to a GLASS library */
int _glassLibraryAddModel(GlassLibrary *library, GlassModel *model);

/* Find a GLASS model in a GLASS library, return NULL if not found */
GlassModel *_glassLibraryFindModel(GlassLibrary *library, const char *name);

/* Find a texture from any of the models in the library */
GlassTexture *_glassLibraryFindTexture(GlassLibrary *library, const char *name);

/* Find a material from any of the models in the library */
GlassMaterial *_glassLibraryFindMaterial(GlassLibrary *library, const char *name);

/* Find a surface from any of the models in the library */
GlassSurface *_glassLibraryFindSurface(GlassLibrary *library, const char *name);

/* Find a variable from any of the models in the library */
GlassVariable *_glassLibraryFindVariable(GlassLibrary *library, const char *name);

/* Find a active point from any of the models in the library */
GlassActivePoint *_glassLibraryFindActivePoint(GlassLibrary *library, const char *name);

/* Remove a GLASS model from a GLASS library */
int _glassLibraryRemoveModel(GlassLibrary *library, GlassModel *model);

/* Free a library */
int _glassFreeLibrary(GlassLibrary *library);

#endif /* __glass_interface_h__ */
