/* 
 * glass - the openGL Articulated Skeleton System
 *
 * Copyright (C) 2001-2003  Robert Ancell <bob27@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __glass_node_h__
#define __glass_node_h__

typedef struct _GlassNode GlassNode;

#include "global.h"
#include "glass_model.h"
#include "glass_transform.h"
#include "glass_surface.h"
#include "glass_apoint.h"

/* A node, ie a transform, surface and active point in an inheritance tree */
struct _GlassNode
{
  GlassTransform *transform;
  GlassSurface *surface;
  GlassActivePoint *apoint;

  /* If this node, or it's children are required for an active point(s) */
  int apoint_transform;

  GlassNode *children, *last_child;

  GlassNode *next;

  /* Loading data */
  int index;
  void *ad;
};

/* Returns an empty node */
GlassNode *_glassNodeNew(void);

/* Set a nodes transform */
void _glassNodeSetTransform(GlassNode *node, GlassTransform *transform);

/* Get a nodes transform */
GlassTransform *_glassNodeGetTransform(GlassNode *node);

/* Set a nodes surface */
void _glassNodeSetSurface(GlassNode *node, GlassSurface *surface);

/* Get a nodes surface */
GlassSurface *_glassNodeGetSurface(GlassNode *node);

/* Set a nodes active point */
void _glassNodeSetActivePoint(GlassNode *node, GlassActivePoint *apoint);

/* Get a nodes active point */
GlassActivePoint *_glassNodeGetActivePoint(GlassNode *node);

/* Add a child to a node */
void _glassNodeAddChild(GlassNode *node, GlassNode *child);

/* Recursively work out which nodes are needed for any active points */
int _glassNodeTestActivePointr(GlassNode *node);

/* Recursively update the active points */
void _glassNodeUpdateActivePointsr(GlassNode *node);

/* Free a node */
void _glassFreeNode(GlassNode *node);

/* Free a node, and (recursively) its siblings/children */
void _glassFreeNoder(GlassNode *node);

#endif /* __glass_node_h__ */
